@@ -1,15 +1,11 @@
 import uuid
 from tracardi_graph_runner.domain.flow import Flow as GraphFlow
-import tracardi.service.storage.crud as crud
-from .entity import Entity
 from .named_entity import NamedEntity
 from .value_object.storage_info import StorageInfo
-from ..exceptions.exception import TracardiException
 from typing import Optional, List
 from pydantic import BaseModel
 from tracardi_graph_runner.domain.flow_graph_data import FlowGraphData, Edge, Position, Node, EdgeBundle
 from tracardi_plugin_sdk.domain.register import MetaData, Plugin, Spec
-from tracardi.service.storage.crud import StorageCrud
 from ..service.secrets import decrypt, encrypt
 import logging
 
@@ -24,10 +20,6 @@ class Flow(GraphFlow):
 
     # Persistence
 
-    def storage(self) -> crud.StorageCrud:
-        flow_record = self.encode()
-        return crud.StorageCrud("flow", FlowRecord, entity=flow_record)
-
     @staticmethod
     def storage_info() -> StorageInfo:
         return StorageInfo(
@@ -38,16 +30,6 @@ class Flow(GraphFlow):
     def encode(self) -> 'FlowRecord':
         return FlowRecord.encode(self)
 
-    @staticmethod
-    async def decode(flow_id) -> 'Flow':
-        flow_record_entity = Entity(id=flow_id)
-        flow_record = await flow_record_entity.storage("flow").load(FlowRecord)  # type: FlowRecord
-
-        if not flow_record:
-            raise TracardiException("Could not find flow `{}`".format(flow_id))
-
-        return flow_record.decode()
-
     def encode_draft(self, draft: 'Flow'):
         self.draft = encrypt(draft.dict())
 
@@ -215,8 +197,15 @@ class FlowRecord(NamedEntity):
 
     # Persistence
 
-    def storage(self) -> StorageCrud:
-        return StorageCrud("flow", FlowRecord, entity=self)
+    # def storage(self) -> StorageCrud:
+    #     return StorageCrud("flow", FlowRecord, entity=self)
+
+    @staticmethod
+    def storage_info() -> StorageInfo:
+        return StorageInfo(
+            'flow',
+            FlowRecord
+        )
 
     @staticmethod
     def encode(flow: Flow) -> 'FlowRecord':
