@@ -4,7 +4,6 @@ from tracardi.domain.value_object.storage_info import StorageInfo
 from tracardi_graph_runner.domain.debug_info import DebugInfo
 from tracardi.domain.entity import Entity
 from tracardi.service.secrets import b64_encoder, b64_decoder
-from tracardi.service.storage.crud import StorageCrud
 
 
 class EventDebugRecord(Entity):
@@ -20,9 +19,12 @@ class EventDebugRecord(Entity):
                     b64 = b64_encoder(debug_info.dict())
                     yield EventDebugRecord(id=debug_info.event.id, content=b64)
 
-    def decode(self) -> DebugInfo:
+    def decode(self, from_dict=False) -> DebugInfo:
         # todo - to pole jest za małe (wyskakuje błąd gdy debug infor ma powyżej 32000 znaków)
-        debug_info = b64_decoder(self.content)
+        if from_dict is True:
+            debug_info = b64_decoder(self['content'])
+        else:
+            debug_info = b64_decoder(self.content)
 
         return DebugInfo(
             **debug_info
@@ -30,9 +32,6 @@ class EventDebugRecord(Entity):
 
     # Persistence
 
-    def storage(self) -> StorageCrud:
-        return StorageCrud("debug-info", EventDebugRecord, entity=self)
-
     @staticmethod
     def storage_info() -> StorageInfo:
         return StorageInfo(
