@@ -2,7 +2,6 @@ from typing import Optional
 
 from tracardi.domain.named_entity import NamedEntity
 from tracardi.domain.value_object.storage_info import StorageInfo
-from tracardi.service.storage.crud import StorageCrud
 
 
 class Segment(NamedEntity):
@@ -16,8 +15,8 @@ class Segment(NamedEntity):
 
     # Persistence
 
-    def storage(self) -> StorageCrud:
-        return StorageCrud("segment", Segment, entity=self)
+    # def storage(self) -> StorageCrud:
+    #     return StorageCrud("segment", Segment, entity=self)
 
     @staticmethod
     def storage_info() -> StorageInfo:
