@@ -1,6 +1,7 @@
 import asyncio
 
-from tracardi.service.storage.crud import EntityStorageCrud
+from tracardi.service.storage.driver import storage
+from tracardi.service.storage.factory import StorageFor
 from tracardi_plugin_sdk.domain.register import Plugin, Spec, MetaData
 from tracardi_plugin_sdk.domain.result import Result
 from tracardi_plugin_sdk.action_runner import ActionRunner
@@ -20,8 +21,7 @@ class DebugPayloadAction(ActionRunner):
 
     async def run(self, **kwargs):
         if self.debug:
-            storage = EntityStorageCrud('event', Event)
-            result = await storage.load_by('type', self.event_type, limit=1)
+            result = await storage.driver.event.load_event_by_type(self.event_type)
 
             if result.total == 0:
                 raise ValueError(
@@ -34,8 +34,8 @@ class DebugPayloadAction(ActionRunner):
 
             profile_entity = Entity(id=self.event.profile.id)
             session_entity = Entity(id=self.event.session.id)
-            profile_task = asyncio.create_task(profile_entity.storage('profile').load(Profile))
-            session_task = asyncio.create_task(session_entity.storage('session').load(Session))
+            profile_task = asyncio.create_task(StorageFor(profile_entity).index('profile').load(Profile))
+            session_task = asyncio.create_task(StorageFor(session_entity).index('session').load(Session))
 
             profile = await profile_task
             session = await session_task
@@ -45,14 +45,13 @@ class DebugPayloadAction(ActionRunner):
                     "Event id `{}` has reference to empty session id `{}`. Debug stopped. This event is corrupted.".format(
                         self.event.id, self.event.session.id))
 
-            self.session.replace(session)
-
             if profile is None:
                 raise ValueError(
                     "Event type `{}` has reference to empty profile id `{}`. Debug stopped. This event is corrupted.".format(
                         self.event.id, self.event.profile.id))
 
             self.profile.replace(profile)
+            self.session.replace(session)
 
             return Result(port="event", value=self.event.dict())
 
