@@ -14,3 +14,7 @@ async def load(id: str) -> Resource:
         raise ValueError('Resource id {} does not exist.'.format(id))
 
     return resource_config_record.decode()
+
+
+async def delete(id: str):
+    return await StorageFor(Entity(id=id)).index("resource").delete()
